@@ -12,23 +12,18 @@
 #include <string>
 
 #if MYGUI_COMPILER == MYGUI_COMPILER_MSVC
- // disable: warning C4275: non dll-interface class '***' used as base for dll-interface clas '***'
-#	pragma warning (push)
-#	pragma warning (disable : 4275)
+	// disable: warning C4275: non dll-interface class '***' used as base for dll-interface clas '***'
+	#pragma warning(push)
+	#pragma warning(disable : 4275)
 #endif
 
 namespace MyGUI
 {
 
-	class MYGUI_EXPORT Exception :
-		public std::exception
+	class MYGUI_EXPORT Exception : public std::exception
 	{
 	public:
-		Exception(const std::string& _description, const std::string& _source, const char* _file, long _line);
-
-		Exception(const Exception& _rhs);
-
-		Exception& operator = (const Exception& _rhs);
+		Exception(std::string _description, std::string _source, std::string _file, long _line);
 
 		virtual const std::string& getFullDescription() const;
 
@@ -53,7 +48,7 @@ namespace MyGUI
 } // namespace MyGUI
 
 #if MYGUI_COMPILER == MYGUI_COMPILER_MSVC
-#	pragma warning (pop)
+	#pragma warning(pop)
 #endif
 
 #endif // MYGUI_EXCEPTION_H_
