@@ -13,15 +13,14 @@
 namespace MyGUI
 {
 
-	class MYGUI_EXPORT IStateInfo :
-		public ISerializable
+	class MYGUI_EXPORT IStateInfo : public ISerializable
 	{
-		MYGUI_RTTI_DERIVED( IStateInfo )
+		MYGUI_RTTI_DERIVED(IStateInfo)
 	};
 
-	typedef std::vector<IStateInfo*> VectorStateInfo;
-	typedef std::map<std::string, IStateInfo*> MapStateInfo;
-	typedef std::map<std::string, VectorStateInfo> MapWidgetStateInfo;
+	using VectorStateInfo = std::vector<IStateInfo*>;
+	using MapStateInfo = std::map<std::string, IStateInfo*, std::less<>>;
+	using MapWidgetStateInfo = std::map<std::string, VectorStateInfo, std::less<>>;
 
 } // namespace MyGUI
 
