@@ -13,21 +13,19 @@
 namespace MyGUI
 {
 
-	class MYGUI_EXPORT SharedLayerNode :
-		public LayerNode
+	class MYGUI_EXPORT SharedLayerNode : public LayerNode
 	{
-		MYGUI_RTTI_DERIVED( SharedLayerNode )
+		MYGUI_RTTI_DERIVED(SharedLayerNode)
 
 	public:
 		explicit SharedLayerNode(ILayer* _layer, ILayerNode* _parent = nullptr);
-		virtual ~SharedLayerNode();
 
 		void addUsing();
 		void removeUsing();
 		size_t countUsing() const;
 
 	private:
-		size_t mCountUsing;
+		size_t mCountUsing{0};
 	};
 
 } // namespace MyGUI
