@@ -16,10 +16,9 @@
 namespace MyGUI
 {
 
-	class MYGUI_EXPORT SimpleText :
-		public EditText
+	class MYGUI_EXPORT SimpleText : public EditText
 	{
-		MYGUI_RTTI_DERIVED( SimpleText )
+		MYGUI_RTTI_DERIVED(SimpleText)
 
 	public:
 		SimpleText();
