@@ -9,6 +9,7 @@
 
 #include "MyGUI_Prerequest.h"
 #include "MyGUI_Any.h"
+#include "MyGUI_EventPair.h"
 #include "MyGUI_ICroppedRectangle.h"
 #include "MyGUI_WidgetUserData.h"
 #include "MyGUI_WidgetInput.h"
@@ -21,7 +22,9 @@
 namespace MyGUI
 {
 
-	typedef delegates::CMultiDelegate3<Widget*, const std::string&, const std::string&> EventHandle_WidgetStringString;
+	using EventHandle_WidgetStringString = EventPairConvertStringView<
+		delegates::MultiDelegate<Widget*, const std::string&, const std::string&>,
+		delegates::MultiDelegate<Widget*, std::string_view, std::string_view>>;
 
 	/** \brief @wpage{Widget}
 		Widget widget description should be here.
@@ -38,11 +41,9 @@ namespace MyGUI
 		// для вызова закрытых деструкторов
 		friend class WidgetManager;
 
-		MYGUI_RTTI_DERIVED( Widget )
+		MYGUI_RTTI_DERIVED(Widget)
 
 	public:
-		Widget();
-
 		/** Create child widget
 			@param _type widget type
 			@param _skin widget skin
@@ -50,44 +51,86 @@ namespace MyGUI
 			@param _align widget align (possible values can be found in enum Align)
 			@param _name if needed (you can use it for finding widget by name later)
 		*/
-		Widget* createWidgetT(const std::string& _type, const std::string& _skin, const IntCoord& _coord, Align _align, const std::string& _name = "");
+		Widget* createWidgetT(
+			std::string_view _type,
+			std::string_view _skin,
+			const IntCoord& _coord,
+			Align _align,
+			std::string_view _name = {});
 
-		/** See Widget::createWidgetT(const std::string& _type, const std::string& _skin, const IntCoord& _coord, Align _align, const std::string& _name = "") */
-		Widget* createWidgetT(const std::string& _type, const std::string& _skin, int _left, int _top, int _width, int _height, Align _align, const std::string& _name = "");
+		/** See Widget::createWidgetT(std::string_view _type, std::string_view _skin, const IntCoord& _coord, Align _align, std::string_view _name = {}) */
+		Widget* createWidgetT(
+			std::string_view _type,
+			std::string_view _skin,
+			int _left,
+			int _top,
+			int _width,
+			int _height,
+			Align _align,
+			std::string_view _name = {});
 
-		/** Create widget using coordinates relative to parent. see Widget::createWidgetT(const std::string& _type, const std::string& _skin, const IntCoord& _coord, Align _align, const std::string& _name = "") */
-		Widget* createWidgetRealT(const std::string& _type, const std::string& _skin, const FloatCoord& _coord, Align _align, const std::string& _name = "");
+		/** Create widget using coordinates relative to parent. see Widget::createWidgetT(std::string_view _type, std::string_view _skin, const IntCoord& _coord, Align _align, std::string_view _name = {}) */
+		Widget* createWidgetRealT(
+			std::string_view _type,
+			std::string_view _skin,
+			const FloatCoord& _coord,
+			Align _align,
+			std::string_view _name = {});
 
-		/** Create widget using coordinates relative to parent. see Widget::createWidgetT(const std::string& _type, const std::string& _skin, const IntCoord& _coord, Align _align, const std::string& _name = "") */
-		Widget* createWidgetRealT(const std::string& _type, const std::string& _skin, float _left, float _top, float _width, float _height, Align _align, const std::string& _name = "");
+		/** Create widget using coordinates relative to parent. see Widget::createWidgetT(std::string_view _type, std::string_view _skin, const IntCoord& _coord, Align _align, std::string_view _name = {}) */
+		Widget* createWidgetRealT(
+			std::string_view _type,
+			std::string_view _skin,
+			float _left,
+			float _top,
+			float _width,
+			float _height,
+			Align _align,
+			std::string_view _name = {});
 
 		// templates for creating widgets by type
 		/** Same as Widget::createWidgetT but return T pointer instead of Widget* */
-		template <typename T>
-		T* createWidget(const std::string& _skin, const IntCoord& _coord, Align _align, const std::string& _name = "")
+		template<typename T>
+		T* createWidget(std::string_view _skin, const IntCoord& _coord, Align _align, std::string_view _name = {})
 		{
 			return static_cast<T*>(createWidgetT(T::getClassTypeName(), _skin, _coord, _align, _name));
 		}
 
 		/** Same as Widget::createWidgetT but return T pointer instead of Widget* */
-		template <typename T>
-		T* createWidget(const std::string& _skin, int _left, int _top, int _width, int _height, Align _align, const std::string& _name = "")
+		template<typename T>
+		T* createWidget(
+			std::string_view _skin,
+			int _left,
+			int _top,
+			int _width,
+			int _height,
+			Align _align,
+			std::string_view _name = {})
 		{
-			return static_cast<T*>(createWidgetT(T::getClassTypeName(), _skin, IntCoord(_left, _top, _width, _height), _align, _name));
+			return static_cast<T*>(
+				createWidgetT(T::getClassTypeName(), _skin, IntCoord(_left, _top, _width, _height), _align, _name));
 		}
 
 		/** Same as Widget::createWidgetRealT but return T* instead of Widget* */
-		template <typename T>
-		T* createWidgetReal(const std::string& _skin, const FloatCoord& _coord, Align _align, const std::string& _name = "")
+		template<typename T>
+		T* createWidgetReal(std::string_view _skin, const FloatCoord& _coord, Align _align, std::string_view _name = {})
 		{
 			return static_cast<T*>(createWidgetRealT(T::getClassTypeName(), _skin, _coord, _align, _name));
 		}
 
 		/** Same as Widget::createWidgetRealT but return T* instead of Widget* */
-		template <typename T>
-		T* createWidgetReal(const std::string& _skin, float _left, float _top, float _width, float _height, Align _align, const std::string& _name = "")
+		template<typename T>
+		T* createWidgetReal(
+			std::string_view _skin,
+			float _left,
+			float _top,
+			float _width,
+			float _height,
+			Align _align,
+			std::string_view _name = {})
 		{
-			return static_cast<T*>(createWidgetRealT(T::getClassTypeName(), _skin, _left, _top, _width, _height, _align, _name));
+			return static_cast<T*>(
+				createWidgetRealT(T::getClassTypeName(), _skin, _left, _top, _width, _height, _align, _name));
 		}
 
 		/** Create child widget
@@ -99,21 +142,34 @@ namespace MyGUI
 			@param _layer layer where widget will be created (all layers usually defined in core_layer.xml file).
 			@param _name optional widget name (you can use it for finding widget by name later)
 		*/
-		Widget* createWidgetT(WidgetStyle _style, const std::string& _type, const std::string& _skin, const IntCoord& _coord, Align _align, const std::string& _layer = "", const std::string& _name = "");
+		Widget* createWidgetT(
+			WidgetStyle _style,
+			std::string_view _type,
+			std::string_view _skin,
+			const IntCoord& _coord,
+			Align _align,
+			std::string_view _layer = {},
+			std::string_view _name = {});
 
 		/** Same as Widget::createWidgetT but return T* instead of Widget* */
-		template <typename T>
-		T* createWidget(WidgetStyle _style, const std::string& _skin, const IntCoord& _coord, Align _align, const std::string& _layer = "", const std::string& _name = "")
+		template<typename T>
+		T* createWidget(
+			WidgetStyle _style,
+			std::string_view _skin,
+			const IntCoord& _coord,
+			Align _align,
+			std::string_view _layer = {},
+			std::string_view _name = {})
 		{
 			return static_cast<T*>(createWidgetT(_style, T::getClassTypeName(), _skin, _coord, _align, _layer, _name));
 		}
 
 		/** Set widget position (position of left top corner) */
-		void setPosition(const IntPoint& _value) override;
+		void setPosition(const IntPoint& _point) override;
 		/** Set widget size */
-		void setSize(const IntSize& _value) override;
+		void setSize(const IntSize& _size) override;
 		/** Set widget position and size */
-		void setCoord(const IntCoord& _value) override;
+		void setCoord(const IntCoord& _coord) override;
 
 		/** See Widget::setPosition(const IntPoint& _pos) */
 		void setPosition(int _left, int _top);
@@ -123,11 +179,11 @@ namespace MyGUI
 		void setCoord(int _left, int _top, int _width, int _height);
 
 		/** Set widget position (position of left top corner)*/
-		void setRealPosition(const FloatPoint& _value);
+		void setRealPosition(const FloatPoint& _point);
 		/** Set widget size */
-		void setRealSize(const FloatSize& _value);
+		void setRealSize(const FloatSize& _size);
 		/** Set widget position and size*/
-		void setRealCoord(const FloatCoord& _value);
+		void setRealCoord(const FloatCoord& _coord);
 
 		/** See Widget::setRealPosition(const FloatPoint& _point) */
 		void setRealPosition(float _left, float _top);
@@ -161,7 +217,7 @@ namespace MyGUI
 		Align getAlign() const;
 
 		/** Set widget opacity */
-		void setAlpha(float _value);
+		void setAlpha(float _alpha);
 		/** Get widget opacity */
 		float getAlpha() const;
 
@@ -175,7 +231,7 @@ namespace MyGUI
 			changes.\n
 			Enabled (true) by default.
 		*/
-		void setInheritsAlpha(bool _value);
+		void setInheritsAlpha(bool _inherits);
 		/** Get inherits alpha mode flag */
 		bool getInheritsAlpha() const;
 
@@ -188,6 +244,7 @@ namespace MyGUI
 		/** Get parent widget or nullptr if no parent */
 		Widget* getParent() const;
 
+		/** Get parent widget size. If there is no parent get layer size */
 		IntSize getParentSize() const;
 
 		/** Get child widgets Enumerator */
@@ -203,12 +260,12 @@ namespace MyGUI
 			Search recursively through all childs starting from this widget.
 			@return Return first found widget with given name
 		*/
-		Widget* findWidget(const std::string& _name);
+		Widget* findWidget(std::string_view _name);
 
 		/** Find all widgets with given name and add them into _result.
 			Search recursively through all childs starting from this widget.
 		*/
-		void findWidgets(const std::string& _name, VectorWidgetPtr& _result);
+		void findWidgets(std::string_view _name, VectorWidgetPtr& _result);
 
 		/** Enable or disable widget */
 		virtual void setEnabled(bool _value);
@@ -230,24 +287,24 @@ namespace MyGUI
 		/** Detach widget from widgets hierarchy
 			@param _layer Attach to specified layer (if any)
 		*/
-		void detachFromWidget(const std::string& _layer = "");
+		void detachFromWidget(std::string_view _layer = {});
 
 		/** Attach widget to parent
 			@param _parent New parent
 			@param _style New widget style (see WidgetStyle::Enum)
 			@param _layer Attach to specified layer (if any)
 		*/
-		void attachToWidget(Widget* _parent, WidgetStyle _style = WidgetStyle::Child, const std::string& _layer = "");
+		void attachToWidget(Widget* _parent, WidgetStyle _style = WidgetStyle::Child, std::string_view _layer = {});
 
 		/** Change widget skin */
-		void changeWidgetSkin(const std::string& _skinName);
+		void changeWidgetSkin(std::string_view _skinName);
 
 		/** Set widget style.
 			@param _style New widget style (see WidgetStyle::Enum)
 			@param _layer Attach to specified layer (if any)
 			@note When choosing WidgetStyle::Popup style you also need attach widget to layer
 		*/
-		void setWidgetStyle(WidgetStyle _style, const std::string& _layer = "");
+		void setWidgetStyle(WidgetStyle _style, std::string_view _layer = {});
 		/** Get widget style */
 		WidgetStyle getWidgetStyle() const;
 
@@ -255,11 +312,11 @@ namespace MyGUI
 			@param _key Property name (for example Alpha or Enabled)
 			@param _value Value converted to string
 		*/
-		void setProperty(const std::string& _key, const std::string& _value);
+		void setProperty(std::string_view _key, std::string_view _value);
 
 
 		/** Event : Widget property changed through setProperty (in code, or from layout)\n
-			signature : void method(MyGUI::Widget* _sender, const std::string& _key, const std::string& _value);
+			signature : void method(MyGUI::Widget* _sender, std::string_view _key, std::string_view _value);
 			@param _sender widget that called this event
 			@param _key
 			@param _value
@@ -272,11 +329,11 @@ namespace MyGUI
 		*/
 		EventHandle_WidgetVoid eventChangeCoord;
 
-        /** Event : Widget is about to be destroyed, but its content is valid at this point.\n
+		/** Event : Widget is about to be destroyed, but its content is valid at this point.\n
             signature : void method(MyGUI::Widget* _sender)
             @param _sender widget that called this event
         */
-        EventHandle_WidgetVoid eventWidgetDestroyed;
+		EventHandle_WidgetVoid eventWidgetDestroyed;
 
 		/*internal:*/
 		// метод для запроса номера айтема и контейнера
@@ -285,7 +342,13 @@ namespace MyGUI
 		// дает приоритет виджету при пиккинге
 		void _forcePick(Widget* _widget);
 
-		void _initialise(WidgetStyle _style, const IntCoord& _coord, const std::string& _skinName, Widget* _parent, ICroppedRectangle* _croppedParent, const std::string& _name);
+		void _initialise(
+			WidgetStyle _style,
+			const IntCoord& _coord,
+			std::string_view _skinName,
+			Widget* _parent,
+			ICroppedRectangle* _croppedParent,
+			std::string_view _name);
 		void _shutdown();
 
 		// удяляет неудачника
@@ -297,12 +360,19 @@ namespace MyGUI
 		void _setAlign(const IntSize& _oldsize, const IntSize& _newSize);
 		bool _checkPoint(int _left, int _top) const;
 
-		Widget* _createSkinWidget(WidgetStyle _style, const std::string& _type, const std::string& _skin, const IntCoord& _coord, Align _align, const std::string& _layer = "", const std::string& _name = "");
+		Widget* _createSkinWidget(
+			WidgetStyle _style,
+			std::string_view _type,
+			std::string_view _skin,
+			const IntCoord& _coord,
+			Align _align,
+			std::string_view _layer = {},
+			std::string_view _name = {});
 
 		// сброс всех данных контейнера, тултипы и все остальное
 		virtual void _resetContainer(bool _update);
 
-		bool _setWidgetState(const std::string& _value);
+		bool _setWidgetState(std::string_view _state);
 
 		// перерисовывает детей
 		void _updateChilds();
@@ -317,7 +387,15 @@ namespace MyGUI
 		void _updateView(); // обновления себя и детей
 
 		// создает виджет
-		Widget* baseCreateWidget(WidgetStyle _style, const std::string& _type, const std::string& _skin, const IntCoord& _coord, Align _align, const std::string& _layer, const std::string& _name, bool _template);
+		Widget* baseCreateWidget(
+			WidgetStyle _style,
+			std::string_view _type,
+			std::string_view _skin,
+			const IntCoord& _coord,
+			Align _align,
+			std::string_view _layer,
+			std::string_view _name,
+			bool _template);
 
 		// удаляет всех детей
 		void _destroyAllChildWidget();
@@ -331,13 +409,13 @@ namespace MyGUI
 		ILayerItem* getLayerItemByPoint(int _left, int _top) const override;
 		const IntCoord& getLayerItemCoord() const override;
 
-		template <typename T>
-		void assignWidget(T*& _widget, const std::string& _name)
+		template<typename T>
+		void assignWidget(T*& _widget, std::string_view _name)
 		{
 			_widget = nullptr;
-			for (VectorWidgetPtr::iterator iter = mWidgetChildSkin.begin(); iter != mWidgetChildSkin.end(); ++iter)
+			for (const auto& iter : mWidgetChildSkin)
 			{
-				Widget* find = (*iter)->findWidget(_name);
+				Widget* find = iter->findWidget(_name);
 				if (nullptr != find)
 				{
 					_widget = find->castType<T>(false);
@@ -346,7 +424,7 @@ namespace MyGUI
 			}
 		}
 
-		VectorWidgetPtr getSkinWidgetsByName(const std::string& _name) const;
+		VectorWidgetPtr getSkinWidgetsByName(std::string_view _name) const;
 
 		virtual void onWidgetCreated(Widget* _widget);
 		virtual void onWidgetDestroy(Widget* _widget);
@@ -356,10 +434,10 @@ namespace MyGUI
 		Widget* _getClientWidget();
 		const Widget* _getClientWidget() const;
 
-		virtual void setPropertyOverride(const std::string& _key, const std::string& _value);
+		virtual void setPropertyOverride(std::string_view _key, std::string_view _value);
 
 	private:
-		const WidgetInfo* initialiseWidgetSkinBase(ResourceSkin* _info, ResourceLayout* _templateInfo);
+		const WidgetInfo* initialiseWidgetSkinBase(ResourceSkin* _skinInfo, ResourceLayout* _templateInfo);
 		void shutdownWidgetSkinBase();
 
 		void _updateAlpha();
@@ -391,7 +469,7 @@ namespace MyGUI
 		// клиентская зона окна
 		// если виджет имеет пользовательские окна не в себе
 		// то обязательно проинициализировать Client
-		Widget* mWidgetClient;
+		Widget* mWidgetClient{nullptr};
 
 		// вектор всех детей виджетов
 		VectorWidgetPtr mWidgetChild;
@@ -400,26 +478,26 @@ namespace MyGUI
 		VectorWidgetPtr mWidgetChildSkin;
 
 		// availability for mouse/keyboard
-		bool mEnabled;
-		bool mInheritedEnabled;
+		bool mEnabled{true};
+		bool mInheritedEnabled{true};
 		// visibility on screen and for mouse
-        bool mVisible;
-		bool mInheritedVisible;
+		bool mVisible{true};
+		bool mInheritedVisible{true};
 		// transparency and transparency inheritance
-		float mAlpha;
-		float mRealAlpha;
-		bool mInheritsAlpha;
+		float mAlpha{ALPHA_MAX};
+		float mRealAlpha{ALPHA_MAX};
+		bool mInheritsAlpha{true};
 		std::string mName;
 
 		// parent in widgets hierarchy
-		Widget* mParent;
+		Widget* mParent{nullptr};
 
-		WidgetStyle mWidgetStyle;
+		WidgetStyle mWidgetStyle{WidgetStyle::Child};
 
-		Widget* mContainer;
+		Widget* mContainer{nullptr};
 
-		Align mAlign;
-		int mDepth;
+		Align mAlign{Align::Default};
+		int mDepth{0};
 	};
 
 } // namespace MyGUI
